.. meta::
    :description lang=en:
        Split a text list in to words / tokens / N-grams of any desired length.
        A Python function for splitting text.

.. automodule:: advertools.word_tokenize
   :members:
   :undoc-members:
   :show-inheritance:
